==> AltTester-Driver-2.0.0.tar.gz: AltTester-Driver-2.0.0/README.md <==
# AltTester Python Bindings

This package contains an library for adding Python language binding to the AltTester framework.

AltTester Unity SDK is an open-source UI driven test automation tool that helps you find objects in your application and interacts with them using tests written in C#, Python or Java.

You can run your tests on real devices (mobile, PCs, etc.) or inside the Unity Editor.

Read the documentation on https://alttester.com/docs/pro/sdk/

## Get Started

Check out the [Get Started](https://alttester.com/docs/pro/sdk/pages/get-started.html) guide from the documentation.

## Development

-   Code Style: [PEP-0008](https://www.python.org/dev/peps/pep-0008/)
-   Docstring style: [Google Style Docstrings](https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html).

### Running Tests

Run the following command to install the dev dependencies:

```
$ pip install -r requirements-dev.txt
```

#### Unit Tests

```
$ pytest tests/unit/
```

#### Integration Tests

```
$ pytest tests/integration/
```

## Contributing

Check out the full contributing guide [contributing](https://alttester.com/docs/pro/sdk/pages/contributing.html).

## Support

Join our Google Group for questions and discussions: https://groups.google.com/a/altom.com/g/alttesterforum

Join our Discord Server to chat with other members of the community: https://discord.gg/Ag9RSuS

## License

Distributed under the **GNU General Public License v3.0**. See [LICENSE](https://github.com/alttester/AltTester-Unity-SDK/blob/master/LICENSE) for more information.

==> AltTester-Driver-2.0.3.tar.gz: AltTester-Driver-2.0.3/README.md <==
# AltTester Python Bindings

This package contains an library for adding Python language binding to the AltTester framework.

AltTester Unity SDK is an open-source UI driven test automation tool that helps you find objects in your application and interacts with them using tests written in C#, Python or Java.

You can run your tests on real devices (mobile, PCs, etc.) or inside the Unity Editor.

Read the documentation on https://alttester.com/docs/sdk/latest/

## Get Started

Check out the [Get Started](https://alttester.com/docs/sdk/latest/pages/get-started.html) guide from the documentation.

## Development

-   Code Style: [PEP-0008](https://www.python.org/dev/peps/pep-0008/)
-   Docstring style: [Google Style Docstrings](https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html).

### Running Tests

Run the following command to install the dev dependencies:

```
$ pip install -r requirements-dev.txt
```

#### Unit Tests

```
$ pytest tests/unit/
```

#### Integration Tests

```
$ pytest tests/integration/
```

## Contributing

Check out the full contributing guide [contributing](https://alttester.com/docs/sdk/latest/pages/contributing.html).

## Support

Join our Google Group for questions and discussions: https://groups.google.com/a/altom.com/g/alttesterforum

Join our Discord Server to chat with other members of the community: https://discord.gg/Ag9RSuS

## License

Distributed under the **GNU General Public License v3.0**. See [LICENSE](https://github.com/alttester/AltTester-Unity-SDK/blob/master/LICENSE) for more information.
